---
title: SMS 본인인증도 테스트 가능한가요?
category: 자주 묻는 질문 (일반 문의) > 일반 문의 > 자주 묻는 질문
tags:
  - 테스트
pgCompanies:
  - 다날
searchTags:
  - 테스트
  - 본인인증 테스트
  - 본인인증 서비스
  - 인증
  - 다날 인증
datetime: 2024-11-11T05:53:52.332Z
---

다날PG사에서 제공하는 SMS본인인증 서비스는 통신사 정책으로 인하여 테스트개발이 어렵습니다.

다날 PG사와 실제 계약을 맺으신 후 발급받는 상점정보로 개발테스트를 진행하시면 됩니다.

<Callout title="본인인증 서비스 종류 보러가기 ↗" />
